# Generated by Django 2.1.5 on 2019-01-09 00:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_db_logger', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='statuslog',
            options={'ordering': ('-create_datetime',), 'verbose_name': 'Logging', 'verbose_name_plural': 'Logging'},
        ),
        migrations.AlterField(
            model_name='statuslog',
            name='create_datetime',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
    ]
